About foresee
=================

This package is under development and will not run properly yet but the goal is:

Provided a time series and a few parameters, foresee can generate forecasts using several time series forecasting models in python and if requested, it can find the best model and results using out of sample forecast accuracy.

Example
=======
[basic example, one-column dataframe, no UI](https://github.com/HamidM6/foresee/blob/master/foresee/examples/basic%20tutorial%2C%20one%20column%20input%20dataframe.ipynb)

[basic example, multi-column dataframe, no UI](https://github.com/HamidM6/foresee/blob/master/foresee/examples/basic%20tutorial%2C%20multi%20column%20input%20dataframe.ipynb)

[basic example, with UI](https://github.com/HamidM6/foresee/blob/master/foresee/examples/drop%20file%20to%20forecast.ipynb)


Documentation
=============

coming soon...

How to get it
=============

coming soon...

Contributing
============
Contributions in any form are welcome, including:

* Documentation improvements
* Additional tests
* New features to existing models
* New models

Discussions take place at foresee channel on slack

[join us on slack](https://join.slack.com/t/openstatworkspace/shared_invite/zt-e6cemrxs-dmHBIpHrZE_U0iciJBu6sA)

Bug Reports
===========

Bug reports can be submitted to the issue tracker at

https://github.com/foresee/foresee/issues

